*----------------------------------------------------------------
*Data
*----------------------------------------------------------------

use publication.dta
keep if industry=="00"&cy_id~=.
sort cy_id dateq
tsset cy_id dateq

label var gap "Country specific inflation (year-on-year log difference)"
label var cp "Overall HICP inflation (year-on-year, in percent)" 
label var GAP "Output gap (in percent of potential GDP)" 
label var GAP_lag4 "Output gap, lagged 4 quarters (in percent of potential GDP)" 
label var GNEER "Nominal effective exchange rate(41 partner countries,year-on-year log difference, in percent)"
label var GNEER_lag4 "Nominal effective exchange rate, lagged 4 quarters (year-on-year log difference, in percent)"
label var GULC_MFG "Unit labor cost in manufacturing (year-on-year log difference, in percent)"
label var GULC_MFG_lag4 "Unit labor cost in manufacturing, lagged 4 quarters (year-on-year log difference, in percent)"
label var TRADE "Exports and imports (as share of GDP)"
label var TRADE_lag4 "Exports and imports, lagged 4 quarters (as share of GDP)"
label var DVAT_MAX_ "Maximum change in VAT rate (in percent)"
label var P_25_DIFF_t0 "Relative price level of household consumption expenditure in 2001 (EU25=1)"

gen GAP_TRADE=GAP*TRADE_lag4
gen GAP_TRADE_lag4=GAP_lag4*TRADE_lag4
gen ULC_TRADE=GULC_MFG*TRADE_lag4
gen ULC_TRADE_lag4=GULC_MFG_lag4*TRADE_lag4


*-------------------------
*Table 1
*------------------------
xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 ///
GAP_TRADE GAP_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* .7380469+GULC_MFG+GULC_MFG_lag4=0
test (GAP_TRADE+GAP_TRADE_lag4)* .7380469+GAP+GAP_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* .7380469+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* .7380469+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg cp l.cp GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* .7380469+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma replace bracket ctitle(Eurozone Overall)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

*--------------------
*Table 2
*--------------------
xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 ///
GAP_TRADE GAP_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test GAP_TRADE+GAP_TRADE_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (GAP_TRADE+GAP_TRADE_lag4)*0.8725677+GAP+GAP_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*0.8725677+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*0.8725677+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="CZE"|cy=="EST"|cy=="HUN"|cy=="LAT"|cy=="LTU"|cy=="POL"|cy=="SLO"|cy=="SVK"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*.9956016+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*0.8725677+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg cp l.cp GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*0.8725677+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone Overall)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 


*-------------------------
*Table 4
*-------------------------
xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE") ///
&sample_half==1, robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* 0.7516458+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma replace bracket ctitle(Eurozone 2002/2003)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE") ///
&sample_half==1, robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* 0.7516458+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone 2002/2003)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE") ///
&sample_half==2, robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* 0.7244479+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone 2004/2005)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE") ///
&sample_half==2, robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* 0.7244479+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone 2004/2005)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE") ///
&sample_half==1, robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*0.8562604+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone 2002/03)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE") ///
&sample_half==1, robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*0.8562604+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone 2002/03)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE") ///
&sample_half==2, robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*0.888875+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone 2004/05)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE") ///
&sample_half==2, robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*0.888875+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone 2004/05)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

*------------------------
*Table 3 
*------------------------

**********************************************************************
*TRADE averages
* Eurozone:  	.7380469 
*    2002/03: 	.7516458 
*    2004/05:  	.7244479
*Non-Eurozone: 	.8725677
*    2002/03:  	.8562604  
*    2004/05:   	.888875 
*
*Average share of country-specific in overall inflation: 
*T: 		 Eurozone:  	-.1162274  Non-Eurozone:  	-2.455984
*   2002/03: Eurozone:  	-.1163622  Non-Eurozone:  	-.3158561
*   2004/05: Eurozone:  	-.1160926  Non-Eurozone:   	-4.596111
*NT: 		 Eurozone:  	-.5328503  NOn-Eurozone:  	-.0436925 
*   2002/03: Eurozone:  	-.3099754  Non-Eurozone:  	-.1007116 
*   2004/05: Eurozone: 		-.7557253   Non-Eurozone:  	.0133267
*01:  	 Eurozone:  	-.9021822  Non-Eurozone:  	.4847788
*   2002/03: Eurozone: 		-.0149272   Non-Eurozone: 	.5328568
*   2004/05: Eurozone:  	-1.789437  Non-Eurozone:  	.4367008 
*Tx01: 	 Eurozone:  	-.3804983  Non-EUrozone:  	.6028468
*   2002/03: Eurozone:  	-.9937374  Non-Eurozone:  	.729367 
*   2004/05: Eurozone:  	.2327408   Non-Eurozone:  	.4763266
**********************************************************************

clear
set mem 1300m
set matsize 800
set maxvar 5000
use publication.dta 

keep if industry=="nt"&cy_id~=.
sort cy_id dateq
tsset cy_id dateq
gen GAP_TRADE=GAP*TRADE_lag4
gen GAP_TRADE_lag4=GAP_lag4*TRADE_lag4
gen ULC_TRADE=GULC_MFG*TRADE_lag4
gen ULC_TRADE_lag4=GULC_MFG_lag4*TRADE_lag4

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* .7380469+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma replace bracket ctitle(Eurozone Tx01)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* .7380469+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma replace bracket ctitle(Eurozone Tx01)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*0.8725677+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone Tx01)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*0.8725677+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone Tx01)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 


clear
set mem 1300m
set matsize 800
set maxvar 5000
use publication.dta 

keep if industry=="t"&cy_id~=.
sort cy_id dateq
tsset cy_id dateq
gen GAP_TRADE=GAP*TRADE_lag4
gen GAP_TRADE_lag4=GAP_lag4*TRADE_lag4
gen ULC_TRADE=GULC_MFG*TRADE_lag4
gen ULC_TRADE_lag4=GULC_MFG_lag4*TRADE_lag4

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* .7380469+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma replace bracket ctitle(Eurozone Tx01)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* .7380469+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma replace bracket ctitle(Eurozone Tx01)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*0.8725677+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone Tx01)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if (cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*0.8725677+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone Tx01)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 


*------------------------
*Table 5 
*------------------------

**********************************************************************
*TRADE averages
* Eurozone:  	.7380469 
*    2002/03: 	.7516458 
*    2004/05:  	.7244479
*Non-Eurozone: 	.8725677
*    2002/03:  	.8562604  
*    2004/05:   	.888875 
*
*Average share of country-specific in overall inflation: 
*T: 		 Eurozone:  	-.1162274  Non-Eurozone:  	-2.455984
*   2002/03: Eurozone:  	-.1163622  Non-Eurozone:  	-.3158561
*   2004/05: Eurozone:  	-.1160926  Non-Eurozone:   	-4.596111
*NT: 		 Eurozone:  	-.5328503  NOn-Eurozone:  	-.0436925 
*   2002/03: Eurozone:  	-.3099754  Non-Eurozone:  	-.1007116 
*   2004/05: Eurozone: 		-.7557253   Non-Eurozone:  	.0133267
*01:  	 Eurozone:  	-.9021822  Non-Eurozone:  	.4847788
*   2002/03: Eurozone: 		-.0149272   Non-Eurozone: 	.5328568
*   2004/05: Eurozone:  	-1.789437  Non-Eurozone:  	.4367008 
*Tx01: 	 Eurozone:  	-.3804983  Non-EUrozone:  	.6028468
*   2002/03: Eurozone:  	-.9937374  Non-Eurozone:  	.729367 
*   2004/05: Eurozone:  	.2327408   Non-Eurozone:  	.4763266
**********************************************************************

clear
set mem 1300m
set matsize 800
set maxvar 5000
use publication.dta 

keep if industry=="nt"&cy_id~=.
sort cy_id dateq
tsset cy_id dateq
gen GAP_TRADE=GAP*TRADE_lag4
gen GAP_TRADE_lag4=GAP_lag4*TRADE_lag4
gen ULC_TRADE=GULC_MFG*TRADE_lag4
gen ULC_TRADE_lag4=GULC_MFG_lag4*TRADE_lag4

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==1 & ///
(cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*  .7516458+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone Tx01 2002/03)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==2 & ///
(cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*  .7244479+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone Tx01 2002/03)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==1 & ///
(cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* .7516458 +GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone Tx01 2004/05)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==2 & ///
(cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* .7244479 +GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone Tx01 2004/05)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 


xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==1 & ///
(cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*.8562604+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone Tx01 2002/03)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==2 & ///
(cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*.888875+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone Tx01 2004/05)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==1 & ///
(cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*.8562604+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone Tx01 2002/03)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==2 & ///
(cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*.888875+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone Tx01 2004/05)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

clear
set mem 1300m
set matsize 800
set maxvar 5000
use publication.dta 

keep if industry=="t"&cy_id~=.
sort cy_id dateq
tsset cy_id dateq
gen GAP_TRADE=GAP*TRADE_lag4
gen GAP_TRADE_lag4=GAP_lag4*TRADE_lag4
gen ULC_TRADE=GULC_MFG*TRADE_lag4
gen ULC_TRADE_lag4=GULC_MFG_lag4*TRADE_lag4

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==1 & ///
(cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*  .7516458+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone Tx01 2002/03)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==2 & ///
(cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*  .7244479+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone Tx01 2002/03)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==1 & ///
(cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* .7516458 +GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone Tx01 2004/05)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==2 & ///
(cy=="AUT"|cy=="BEL"|cy=="FIN"|cy=="FRA"|cy=="GER"|cy=="IRE"|cy=="ITA"|cy=="LUX"|cy=="NET"|cy=="POR"|cy=="SPA"|cy=="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)* .7244479 +GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Eurozone Tx01 2004/05)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 


xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==1 & ///
(cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*.8562604+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone Tx01 2002/03)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap l.gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==2 & ///
(cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*.888875+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone Tx01 2004/05)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==1 & ///
(cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*.8562604+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone Tx01 2002/03)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

xtreg gap GAP GAP_lag4 GNEER GNEER_lag4 GULC_MFG GULC_MFG_lag4 ///
ULC_TRADE ULC_TRADE_lag4 TRADE_lag4 ///
P_25_DIFF_t0 ///
DVAT_MAX_ ///
if sample_half==2 & ///
(cy~="AUT"&cy~="BEL"&cy~="FIN"&cy~="FRA"&cy~="GER"&cy~="IRE"&cy~="ITA"&cy~="LUX"&cy~="NET"&cy~="POR"&cy~="SPA"&cy~="GRE"), robust
test GAP+GAP_lag4=0
test GNEER+GNEER_lag4=0
test GULC_MFG+GULC_MFG_lag4=0
test ULC_TRADE+ULC_TRADE_lag4=0
test (ULC_TRADE+ULC_TRADE_lag4)*.888875+GULC_MFG+GULC_MFG_lag4=0
outreg using Final_tables.xls, comma append bracket ctitle(Non-Eurozone Tx01 2004/05)  3aster nolabel pvalue tdec(2)  ///
addstat(R-squared (within), e(r2_w), R-squared (between), e(r2_b), R-squared (overall), e(r2_o)) adec(4) 

